@@ -202,11 +202,10 @@ def stream_sqlite(sqlite_chunks, max_buffer_size):
                 m = 32 * (u - 12) // 255 - 23
                 k = m + (p - m) % (u - 4)
 
-                return (
+                return \
                     p if p <= x else \
                     k if k <= x else \
                     m
-                )
 
             def read_table_row(rowid, cell_num_reader, cell_varint_reader):
 
@@ -244,17 +243,20 @@ def stream_sqlite(sqlite_chunks, max_buffer_size):
                 def table_info_and_row_constructor(cur, master_row):
                     cur.execute(master_row.sql)
                     cur.execute("PRAGMA table_info('" + master_row.name.replace("'","''") + "');")
-                    columns = cur.fetchall()
-                    row_constructor = namedtuple('Row', ('rowid',) + tuple(column[1] for column in columns))
-                    return tuple(column_constructor(*column) for column in columns), row_constructor
+                    columns = tuple(column_constructor(*column) for column in cur.fetchall())
+                    integer_primary_key_indexes = tuple(i for i, column in enumerate(columns) if column.pk and column.type.lower() == 'integer')
+                    rowid_alias_index = integer_primary_key_indexes[0] if len(integer_primary_key_indexes) == 1 else None
+                    row_namedtuple = namedtuple('Row', tuple(column.name for column in columns))
+                    row_constructor = lambda rowid, *values: row_namedtuple(*tuple((rowid if i == rowid_alias_index else value) for i, value in enumerate(values)))
+
+                    return columns, row_constructor
 
                 def process_master_leaf_row(rowid, cell_num_reader, cell_varint_reader):
                     master_row = read_table_row(rowid, cell_num_reader, cell_varint_reader)
-                    yield from (
+                    yield from \
                         process_if_buffered_or_remember(partial(process_table_page, master_row.name, *table_info_and_row_constructor(cur, master_row)), master_row.rootpage) if master_row.type == 'table' else \
                         process_if_buffered_or_remember(process_index_page, master_row.rootpage) if master_row.type == 'index' else \
                         ()
-                    )
 
                 _, num_cells, _, _ = table_leaf_header.unpack(page_reader(7))
 
@@ -309,25 +311,23 @@ def stream_sqlite(sqlite_chunks, max_buffer_size):
                     partial(process_table_page, table_name, table_info, row_constructor), right_most_pointer)
 
             page_type = page_reader(1)
-            yield from (
+            yield from \
                 process_table_leaf_master() if page_type == LEAF_TABLE and table_name == 'sqlite_schema' else \
                 process_table_leaf_non_master() if page_type == LEAF_TABLE else \
                 process_table_interior()
-            )
 
         def process_index_page(page_bytes, page_reader):
 
             def get_index_initial_payload_size(p):
                 u = len(page_bytes)
-                x = (u - 12 ) * 64 // 255 -23
+                x = 64 * (u - 12) // 255 - 23
                 m = 32 * (u - 12) // 255 - 23
                 k = m + (p - m) % (u - 4)
 
-                return (
+                return \
                     p if p <= x else \
                     k if k <= x else \
                     m
-                )
 
             def process_index_leaf():
 
@@ -373,10 +373,9 @@ def stream_sqlite(sqlite_chunks, max_buffer_size):
                 yield from process_if_buffered_or_remember(process_index_page, right_most_pointer)
 
             page_type = page_reader(1)
-            yield from (
+            yield from \
                 process_index_leaf() if page_type == LEAF_INDEX else \
                 process_index_interior()
-            )
 
         def process_freelist_trunk_page(page_bytes, page_reader):
             next_trunk, num_leaves = freelist_trunk_header.unpack(page_reader(8))
